# Fancy Abak

![PyPI - Downloads](https://img.shields.io/pypi/dm/fancy-abak)
![PyPI](https://img.shields.io/pypi/v/fancy-abak?style=flat)
CLI tool to use ABAK

- [Fancy Abak](#fancy-abak)
  - [Requirements](#requirements)
  - [Installation](#installation)
    - [MacOS](#macos)

## Requirements

- (Tested and built using) Python >3.10

## Installation

Package is available in PyPi:

```shell
pip install fancy-abak
```

### MacOS

Package is available in brew:

```shell
brew tap gcarrarom/fancygui
brew install gcarrarom/fancygui/fancy-abak
```
